Trait ndarray::linalg::Dot [−][src]
Matrix Multiplication
For two-dimensional arrays, the dot method computes the matrix multiplication.
Associated Types
Required methods
Implementors
Compute the dot product of one-dimensional arrays.
The dot product is a sum of the elementwise products (no conjugation of complex operands, and thus not their inner product).
Panics if the arrays are not of the same length.
Note: If enabled, uses blas dot for elements of f32, f64 when memory
layout allows.
type Output = A
Perform the matrix multiplication of the rectangular array self and
column vector rhs.
The array shapes must agree in the way that
if self is M × N, then rhs is N.
Return a result array with shape M.
Panics if shapes are incompatible.
Perform the matrix multiplication of the row vector self and
rectangular matrix rhs.
The array shapes must agree in the way that
if self is M, then rhs is M × N.
Return a result array with shape N.
Panics if shapes are incompatible.